/*
   Пины, на которых расположен индикатор

   5-й пин - точка
   6-й пин - нижний правый светодиод (c)
   7-й пин - нижний светодиод (d)
   8-й пин - нижний левый светодиод (e)
   9-й пин - верхний правый светодиод (b)
   10-й пин - верхний светодиод (a)
   11-й пин - верхний левый светодиод (f)
   12-й пин - средний свтеодиод (g)
 */
int pins[8] = {5, 6, 7, 8, 9, 10, 11, 12};

/*

   Массив массивов единиц и нулей. Каждый элемент
   массива является другим массивом, обозначающим,
   какие пины (по порядку, начиная с шестого,
   то есть с pins[1]) должны быть включены, чтобы 
   загорелась соответствующая цифра

   1 означает, что пин должен быть включён
   0 означает, что пин должен быть выключен
 */
boolean digits[10][7] = {
    {1,1,1,1,1,1,0},
    {1,0,0,1,0,0,0},
    {0,1,1,1,1,0,1},
    {1,1,0,1,1,0,1},
    {1,0,0,1,0,1,1},
    {1,1,0,0,1,1,1},
    {1,1,1,0,1,1,1},
    {1,0,0,1,1,0,0},
    {1,1,1,1,1,1,1},
    {1,1,0,1,1,1,1}
};

/*
   Процедура, отображающая на индикаторе
   определённую цифру
 */
void showDigit(int num)
{
    // Пробегаемся по элементам массива digits
    // и смотрим, если на i-м месте этого элемента
    // стоит 1, включаем соответствующий пин,
    // если 0 - выключаем
    for (int i = 0; i < 7; i++)
        digitalWrite(pins[i+1], digits[num][i]);
}

void setup()
{
    // Для каждого светодиода в индикаторе
    // инициализируем пин, соответствующий ему,
    // как работающий на вывод
    for (int i = 0; i < 8; i++)
        pinMode(pins[i], OUTPUT);
}

void loop() {
    // Пробегаем все цифры от 0 до 9 и выводим их
    // После каждой ждём одну секунду
    for (int i = 0; i <= 9; i++) {
        showDigit(i);
        delay(1000);    
    }
}
